From c5fdaef450e6f6b4fbb63d27c8c5a7583d4d3dad Mon Sep 17 00:00:00 2001
From: Palana <palana@stunned.de>
Date: Thu, 4 Sep 2014 06:31:41 +0200
Subject: [PATCH] Fix crash when closing the properties window on OSX

Followup to d56432304e6e8ae00ea66bef8c1847894e5cac9f, it apparently
still crashed (on slower machines?) when closing the properties window
via mouse (by clicking the X button)
---
 obs/window-basic-properties.cpp | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/obs/window-basic-properties.cpp b/obs/window-basic-properties.cpp
index eaefbb121..75a94612a 100644
--- a/obs/window-basic-properties.cpp
+++ b/obs/window-basic-properties.cpp
@@ -145,10 +145,11 @@ void OBSBasicProperties::closeEvent(QCloseEvent *event)
 	if (!event->isAccepted())
 		return;
 
 	// remove draw callback in case our drawable surfaces go away before
 	// the destructor gets called
 	obs_display_remove_draw_callback(display,
 			OBSBasicProperties::DrawPreview, this);
+	display = nullptr;
 
 	config_set_int(App()->GlobalConfig(), "PropertiesWindow", "cx",
 			width());
@@ -145,10 +145,11 @@ void OBSBasicProperties::closeEvent(QCloseEvent *event)
 		return;
 
-	// remove draw callback in case our drawable surfaces go away before
-	// the destructor gets called
+	// remove draw callback and release display in case our drawable
+	// surfaces go away before the destructor gets called
 	obs_display_remove_draw_callback(display,
 			OBSBasicProperties::DrawPreview, this);
-- 
GitLab